@@ -1,7 +1,7 @@
 package Complete::Path;
 
 our $DATE = '2015-09-09'; # DATE
-our $VERSION = '0.14'; # VERSION
+our $VERSION = '0.15'; # VERSION
 
 use 5.010001;
 use strict;
@@ -228,6 +228,8 @@ sub complete_path {
                              qr/\A\Q$s\E(?:\Q$path_sep\E)?\z/);
             };
             #say "D:  re=$re";
+            my $num_exact_matches = 0;
+            my $exact_match_path;
             for (@$listres) {
                 #say "D:  $_";
                 my $s = $_; $s =~ s/_/-/g if $map_case;
@@ -235,8 +237,22 @@ sub complete_path {
                 next unless $s =~ $re;
                 my $p = $dir =~ $re_ends_with_path_sep ?
                     "$dir$_" : "$dir$path_sep$_";
+                if ($ci ? lc($s) eq lc($intdir) : $s eq $intdir) {
+                    $num_exact_matches++;
+                    $exact_match_path = $p;
+                }
                 push @new_candidate_paths, $p;
             }
+
+            # when doing exp_im_path, check if we have a single exact match. in
+            # that case, don't use all the candidates because that can be
+            # annoying, e.g. you have 'a/foo' and 'and/food', you won't be able
+            # to complete 'a/f' because bash (e.g.) will always cut the answer
+            # to 'a' because the candidates are 'a/foo' and 'and/foo' (it will
+            # use the shortest common string which is 'a').
+            if ($num_exact_matches == 1) {
+                @new_candidate_paths = ($exact_match_path);
+            }
         }
         #say "D:  candidate_paths=[",join(", ", map{"<$_>"} @new_candidate_paths),"]";
         return [] unless @new_candidate_paths;
@@ -320,7 +336,7 @@ Complete::Path - Complete path
 
 =head1 VERSION
 
-This document describes version 0.14 of Complete::Path (from Perl distribution Complete-Path), released on 2015-09-09.
+This document describes version 0.15 of Complete::Path (from Perl distribution Complete-Path), released on 2015-09-09.
 
 =head1 DESCRIPTION
 
